/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.application;

import javax.faces.bean.ApplicationScoped;
import javax.faces.bean.ManagedBean;

import kieker.webgui.beans.IProjectBean;

/**
 * This bean is a helper class to change for example from the analysis editor to the cockpit. It clears the source bean (by using the clear-method) and sets the
 * project name of the new destination bean, returning its return value.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@ApplicationScoped
public class ForwardBean {

	/**
	 * Default constructor.
	 */
	public ForwardBean() {
		// No code necessary.
	}

	/**
	 * Moves from one page to another. This method clears the source bean (by using the clear-method) and sets the
	 * project name of the new destination bean, returning its return value.
	 * 
	 * @param sourceBean
	 *            The source bean.
	 * @param destinationBean
	 *            The destination bean.
	 * @return The return value of the destination bean.
	 */
	public String forward(final IProjectBean sourceBean, final IProjectBean destinationBean) {
		final String projectName = sourceBean.getProjectName();

		sourceBean.clearProject();

		return destinationBean.setProject(projectName);
	}
}
